@@ -1,8 +1,8 @@
 from __future__ import absolute_import
 
-from requests_api.api import RequestsAPI
+from requests_api.core import Requests
 from requests_api.adapter import RetryAdapter
-from requests_api.exception import RequestsAPIConfigurationError
+from requests_api.errors import RequestError, HTTPError
 from requests_api.auth import (
     basic_auth,
     digest_auth,
@@ -10,16 +10,15 @@ from requests_api.auth import (
     ntlm_auth,
     kerberos_auth
 )
-from requests_api.core import pass_requests
 
 __all__ = [
-    "RequestsAPI",
+    "Requests",
     "RetryAdapter",
-    "RequestsAPIConfigurationError",
+    "RequestError",
+    "HTTPError",
     "basic_auth",
     "digest_auth",
     "oauth2_auth",
     "ntlm_auth",
-    "kerberos_auth",
-    "pass_requests"
+    "kerberos_auth"
 ]
